<p align="center">
<a href="https://github.com/Kajiih/kajihs-utils">
    <img alt="Kajih's Utils" src="https://www.python.org/static/community_logos/python-logo-generic.svg"/>
</a>
</p>

<p align="center">
    <em>Totally typed, plausibly practical, and remarkably random utilities—for me, and maybe for you too.</em>
</p>

---

**Documentation**: <https://Kajiih.github.io/kajihs-utils/>

**Source Code**: <https://github.com/Kajiih/kajihs-utils>

---
